@@ -1230,8 +1230,8 @@ void POSet::RecursiveComputeMRP(
         for (std::uint_fast64_t y = 0; y < elementi->size(); ++y) {
             if (poset_elements_used[y]) {
                 std::vector<std::uint_fast64_t> diff;
-                auto ideal1 = __lattice_of_ideals->TreeOfIdeals().ideals().at(v_primo);
-                auto ideal2 = __lattice_of_ideals->TreeOfIdeals().ideals().at(v);
+                auto ideal1 = __lattice_of_ideals->getTreeOfIdeals().ideals().at(v_primo);
+                auto ideal2 = __lattice_of_ideals->getTreeOfIdeals().ideals().at(v);
                 std::set_difference(ideal1->begin(), ideal1->end(), ideal2->begin(), ideal2->end(), std::inserter(diff, diff.begin()));
                 std::uint_fast64_t x = diff.front();
                 auto x_converted = __tree_of_ideals->leForConversion()->getVal(x - 1);
@@ -1242,8 +1242,8 @@ void POSet::RecursiveComputeMRP(
         }
         if ((v_primo != __lattice_of_ideals->Top()) && !lattice_elements_used[v_primo]) {
             std::vector<std::uint_fast64_t> diff;
-            auto ideal1 = __lattice_of_ideals->TreeOfIdeals().ideals().at(v_primo);
-            auto ideal2 = __lattice_of_ideals->TreeOfIdeals().ideals().at(v);
+            auto ideal1 = __lattice_of_ideals->getTreeOfIdeals().ideals().at(v_primo);
+            auto ideal2 = __lattice_of_ideals->getTreeOfIdeals().ideals().at(v);
             std::set_difference(ideal1->begin(), ideal1->end(), ideal2->begin(), ideal2->end(), std::inserter(diff, diff.begin()));
             std::uint_fast64_t label = diff.front();
             auto label_converted = __tree_of_ideals->leForConversion()->getVal(label - 1);
